# Contributors

BioSimulators-MASSpy was developed with help from the following people:

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://www.karrlab.org"><img src="https://avatars.githubusercontent.com/u/2848297?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Jonathan Karr</b></sub></a><br /><a href="https://github.com/biosimulators/Biosimulators_MASSpy/commits?author=jonrkarr" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/z-haiman"><img src="https://avatars.githubusercontent.com/u/29131681?v=4?s=100" width="100px;" alt=""/><br /><sub><b>z-haiman</b></sub></a><br /><a href="#tool-z-haiman" title="Tools">🔧</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

A key to these emojis is available [here](https://allcontributors.org/docs/en/emoji-key).

## Contributing to BioSimulators-MASSpy
We enthusiastically welcome contributions! Please see the [guide to contributing](CONTRIBUTING.md) and the [developer's code of conduct](CODE_OF_CONDUCT.md). 
